<?php

/**
 * Class Kupindo
 *
 * Responsible for processing and generating feed for Kupindo.com
 *
 * @since 1.0.0
 * @package Kupindo
 *
 */
class Kupindo_Feed_Kupindo
{

    /**
     * This variable is responsible for holding all product attributes and their values
     *
     * @since   1.0.0
     * @var     array $products Contains all the product attributes to generate feed
     * @access  public
     */
    public $products;

    /**
     * This variable is responsible for holding feed configuration form values
     *
     * @since   1.0.0
     * @var     array $rules Contains feed configuration form values
     * @access  public
     */
    public $rules;

    /**
     * This variable is responsible for mapping store attributes to merchant attribute
     *
     * @since   1.0.0
     * @var     array $mapping Map store attributes to merchant attribute
     * @access  public
     */
    public $mapping;

    /**
     * This variable is responsible for generate error logs
     *
     * @since   1.0.0
     * @var     array $errors hold error logs
     * @access  public
     */
    public $errors;

    /**
     * This variable is responsible for generate error logs
     *
     * @since   1.0.0
     * @var     array $warnings hold warnings logs
     * @access  public
     */
    public $warnings;

    /**
     * This variable is responsible for making error number
     *
     * @since   1.0.0
     * @var     int $errorCounter Generate error number
     * @access  public
     */
    public $errorCounter;

    /**
     * Feed Wrapper text for enclosing each product information
     *
     * @since   1.0.0
     * @var     string $feedWrapper Feed Wrapper text
     * @access  public
     */
    public $feedWrapper = 'Predmet';

    /**
     * Store product information
     *
     * @since   1.0.0
     * @var     array $storeProducts
     * @access  public
     */
    private $storeProducts;

    /**
     * Define the core functionality to generate feed.
     *
     * Set the feed rules. Map products according to the rules and Check required attributes
     * and their values according to merchant specification.
     * @var Woo_Generate_Feed $feedRule Contain Feed Configuration
     * @since    1.0.0
     */
    public function __construct($feedRule)
    {
        $products = new Kupindo_Feed_Products();
        $storeProducts = $products->kupindo_feed_get_visible_product($feedRule);		
        if(!empty($storeProducts)){
            $engine = new WF_Engine($storeProducts, $feedRule);
            $this->products = $engine->mapProductsByRules();
            $this->rules = $feedRule;
			$this->mapAttributeForXML();
        }else{
            $this->products=array();
        }
    }


    /**
     * Return Feed
     * @return array
     */
    public function returnFinalProduct()
    {
        if(!empty($this->products)){
            $engine = new WF_Engine($this->products, $this->rules);
            if ($this->rules['feedType'] == 'xml') {
                //return $this->get_feed($this->products);
                $feed=array(
                    "header"=>$this->get_xml_feed_header(),
                    "body"=>$this->get_xml_feed($this->products),
                    "footer"=>$this->get_xml_feed_footer(),
                );
                return $feed;
            }  elseif ($this->rules['feedType'] == 'txt') {
                //return $engine->get_txt_feed();
                $feed=array(
                    "body"=>$engine->get_txt_feed(),
                    "header"=>$engine->txtFeedHeader,
                    "footer"=>"",
                );
                return $feed;
            } elseif ($this->rules['feedType'] == 'csv') {
                //return $engine->get_csv_feed();
                $feed=array(
                    "body"=>$engine->get_csv_feed(),
                    "header"=>$engine->csvFeedHeader,
                    "footer"=>"",
                );
                return $feed;
            }
        }

        $feed=array(
            "body"=>"",
            "header"=>"",
            "footer"=>"",
        );
        return $feed;
    }

    /**
     * Configure merchant attributes for XML feed
     */
    public function mapAttributeForXML()
    {		
        $kupindoXMLAttribute = array(
			"availability" => array("Aktivan", false),
			"product_category" => array("IDPodKategorija", false),
			"sku" => array("GTIN", false),
			"id" => array("IDInterni", false),
			"title" => array("Naziv", true),
			"description" => array("Opis", true),
			"garantni_list" => array("Garancija", false),
			"duzina_garancije" => array("DuzinaGarancije", true),
			"price" => array("Cena", false),
			"sale_price" => array("AkcijskaCena", false),
			"quantity" => array("Kolicina", false),
			"images" => array("Images", true),
			"upc" => array("ISBN", false),
			"condition" => array("Stanje", false),
			"nacin_slanja" => array("NacinSlanja", false),
			"nacin_placanja" => array("NacinPlacanja", false),
			"besplatna_dostava" => array("BesplatnaDostava", false),
			"youtube_video" => array("YoutubeURL", false, )
        );

        if (count($this->products)) {
            foreach ($this->products as $no => $product) {
                // $this->identifier_status_add($no);
                foreach ($product as $key => $value) {
                    $this->mapAttribute($no, $key, $kupindoXMLAttribute[$key][0], $value, $kupindoXMLAttribute[$key][1]);
                }
                // $this->process_kupindo_shipping_attribute_for_xml($no);
            }
        }
    }

    /**
     * Map to kupindo attribute
     * @param $no
     * @param $from
     * @param $to
     * @param $value
     * @param bool $cdata
     * @return array
     */
    public function mapAttribute($no, $from, $to, $value, $cdata = false)
    {
        unset($this->products[$no][$from]);
		if($to=='AkcijskaCena'){
			return false;
		}	
		
		if($to=='Cena'){	
			if(get_option('kupindo_use_sale_price') == 1){
				if($this->products[$no]['sale_price'] > 0){
					$value = $this->products[$no]['sale_price'];
				} else {
					$value = $value;
				}
			} else {
				$value = $value;
			}
			print_r($value);
		}
		
		if($to=='Stanje'){
			$value = str_replace("New","1",$value);
			$value = str_replace("Used","0",$value);
		}	
		
		if($to=='Aktivan'){
			$value = str_replace("in stock","1",$value);
			$value = str_replace("out of stock","0",$value);
		}	
		
		if($to=='NacinSlanja'){
			$tmpValue = "";
			$nacinSlanjaArray = explode(",", $value);
			foreach($nacinSlanjaArray as $nacin_slanja){
				$tmpValue .= '<Slanje>' . $nacin_slanja .  '</Slanje>';
			}
			$value = $tmpValue;
		}
		
		if($to=='NacinPlacanja'){
			$tmpValue = "";
			$nacinPlacanjaArray = explode(",", $value);
			foreach($nacinPlacanjaArray as $nacin_placanja){
				$tmpValue .= '<Placanje>' . $nacin_placanja .  '</Placanje>';
			}	
			$value = $tmpValue;
		}
		
        if ($this->rules['feedType'] == 'xml') {
            return $this->products[$no][$to] = $this->formatXMLLine($to, $value, $cdata);
        } else {
            return $this->products[$no][$to] = $value;
        }
    }

    public function identifier_status_add($no)
    {
        $identifier = array('brand', 'upc', 'sku', 'mpn', 'gtin');
        $product = $this->products[$no];

        if(!array_key_exists('g:identifier_exists',$product)) {
            if (count(array_intersect_key(array_flip($identifier), $product)) >= 2) {
                # Any 2 required keys exist!
                $countIdentifier=0;
                if(array_key_exists('brand',$product) && !empty($product['brand'])){
                    $countIdentifier++;
                }
                if(array_key_exists('upc',$product) && !empty($product['upc'])){
                    $countIdentifier++;
                }
                if(array_key_exists('sku',$product) && !empty($product['sku'])){
                    $countIdentifier++;
                }
                if(array_key_exists('mpn',$product) && !empty($product['mpn'])){
                    $countIdentifier++;
                }
                if(array_key_exists('gtin',$product) && !empty($product['gtin'])){
                    $countIdentifier++;
                }
                if($countIdentifier>=2){
                    $this->products[$no]["g:identifier_exists"] = $this->formatXMLLine("g:identifier_exists", "yes", $cdata = true);
                }else{
                    $this->products[$no]["g:identifier_exists"] = $this->formatXMLLine("g:identifier_exists", "no", $cdata = true);
                }
            } else {
                $this->products[$no]["g:identifier_exists"] = $this->formatXMLLine("g:identifier_exists", "no", $cdata = true);
            }
        }
    }


    /**
     * @param $no
     * @return bool|string
     */
    public function process_kupindo_shipping_attribute_for_xml($no)
    {
        $shipping = array('g:shipping_country', 'g:shipping_service', 'g:shipping_price', 'g:shipping_region');
        $shippingAttr = array();
        $products = $this->products[$no];
        foreach ($products as $keyAttr => $valueAttr) {
            if (in_array($keyAttr, $shipping)) {
                array_push($shippingAttr, array($keyAttr => $valueAttr));
                unset($this->products[$no][$keyAttr]);
            }
        }
        if (count($shippingAttr)) {
            $str = "";
            foreach ($shippingAttr as $key => $attributes) {
                foreach ($attributes as $keyAttr => $valueAttr) {
                    $str .= str_replace("shipping_", "", $valueAttr);
                }
            }
            return $this->products[$no]['g:shipping'] = $this->formatXMLLine("g:shipping", $str, false);
        }
        return false;
    }

	
    function formatXMLLine($attribute, $value, $cdata, $space = "")
    {
        //Make single XML  node
        if (!empty($value))
            $value = trim($value);
        if (gettype($value) == 'array')
            $value = json_encode($value);
        if (strpos($value, "<![CDATA[") === false && substr(trim($value), 0, 4) == "http") {
            $value = "<![CDATA[$value]]>";
        } elseif (strpos($value, "<![CDATA[") === false && $cdata === true && !empty($value)) {
            $value = "<![CDATA[$value]]>";
        } else if ($cdata) {
            if(!empty($value)){
                $value = "<![CDATA[$value]]>";
            }
        }
		
		$value = str_replace("<![CDATA[<![CDATA[", "<![CDATA[", $value);
		$value = str_replace("]]>]]>", "]]>", $value);
		
		/* specific attributes and fixes */
		if($attribute == 'Images'){
			$value = str_replace("<![CDATA[", "", $value);
			$value = str_replace("]]>", "", $value);
			return "
			$space<Images type=\"array\"><ImageURL>$value</ImageURL></Images>";
		} elseif($attribute == 'NacinSlanja') {
			return "
			$space<NacinSlanja type=\"array\">$value</NacinSlanja>";
		} elseif($attribute == 'NacinPlacanja') {	
			return "
			$space<NacinPlacanja type=\"array\">$value</NacinPlacanja>";
		} else {
			return "
			$space<$attribute>$value</$attribute>";
		}	
    }



    public function get_xml_feed_header()
    {
        $output = '<Prodavnica>';
		$output .= "\n";
        $output .= '<PredmetiLista type="array">';
        return $output;
    }

    public function get_xml_feed($items)
    {
        $feed = "";
        //$feed .= $this->get_feed_header();
        $feed .= "\n";
        if ($items) {
            foreach ($items as $item => $products) {
                $feed .= "      <" . $this->feedWrapper . ">";

                foreach ($products as $key => $value) {
                    if (!empty($value)){
                        $feed .= $value;
                    }
                }
                $feed .= "\n      </" . $this->feedWrapper . ">\n";
            }
            //$feed .= $this->get_feed_footer();

            return $feed;
        }
        return false;
    }

    public function get_xml_feed_footer()
    {
        $footer = "</PredmetiLista>";
		$footer .= "\n";
		$footer .= "</Prodavnica>";
        return $footer;
    }

    public function short_products()
    {
        if ($this->products) {
            update_option('wpf_progress', "Shorting Products");
            sleep(1);
            $array = array();
            $ij = 0;
            foreach ($this->products as $key => $item) {
                $array[$ij] = $item;
                unset($this->products[$key]);
                $ij++;
            }
            return $this->products = $array;
        }
        return $this->products;
    }


}